/*
 * MIT License
 *
 * Copyright (c) 2021 Gourav Khunger
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.github.gouravkhunger.jekyllex.ui.editor.pagerAdapter

import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentActivity
import androidx.viewpager2.adapter.FragmentStateAdapter
import com.github.gouravkhunger.jekyllex.ui.editor.fragments.EditingFragment
import com.github.gouravkhunger.jekyllex.ui.editor.fragments.PreviewFragment

// The adapter for the ViewPager in the Markdown editor activity
class ViewPagerAdapter(
    fragmentActivity: FragmentActivity
) : FragmentStateAdapter(fragmentActivity) {

    // Constant values for this class
    companion object {
        internal const val EDITOR_SCREEN_POSITION = 0
        internal const val PREVIEW_SCREEN_POSITION = 1
    }

    // This function returns the total items in the Tab Layout.
    override fun getItemCount(): Int {
        return 2
    }

    // Function to create the fragments at their specific positions.
    override fun createFragment(position: Int): Fragment = when (position) {
        EDITOR_SCREEN_POSITION -> EditingFragment()
        PREVIEW_SCREEN_POSITION -> PreviewFragment()
        else -> throw IllegalStateException("Invalid adapter position")
    }
}
